"""
Constants and configuration values for Amazon Affiliate marketing.

This module contains useful constants, commission rates, and configuration
values that affiliate marketers commonly reference.
"""

# Amazon Associates Commission Rates by Category (as of 2024)
COMMISSION_RATES = {
    "luxury_beauty": 10.0,
    "amazon_games": 20.0,
    "digital_music": 5.0,
    "physical_books": 4.5,
    "kitchen": 4.0,
    "automotive": 3.0,
    "electronics": 2.0,
    "home_garden": 3.0,
    "sports_outdoors": 3.0,
    "tools_home_improvement": 3.0,
    "toys_games": 3.0,
    "baby_products": 3.0,
    "health_personal_care": 1.0,
    "grocery": 1.0,
    "pet_products": 3.0,
    "fashion": 4.0,
    "jewelry": 2.0,
    "shoes_handbags": 7.0,
    "furniture": 8.0,
    "home_decor": 8.0,
    "lawn_garden": 3.0,
    "business_industrial": 3.0,
    "musical_instruments": 3.0,
    "video_games": 1.0,
    "wireless_accessories": 6.0
}

# Amazon Associates Program Countries
SUPPORTED_COUNTRIES = [
    "United States",
    "United Kingdom", 
    "Canada",
    "Germany",
    "France",
    "Italy",
    "Spain",
    "Japan",
    "India",
    "Brazil",
    "Mexico",
    "Australia"
]

# Common Affiliate Marketing Keywords
HIGH_INTENT_KEYWORDS = [
    "best",
    "review",
    "buy",
    "compare",
    "vs",
    "top",
    "guide",
    "how to choose",
    "buying guide",
    "recommended",
    "discount",
    "deal",
    "sale",
    "cheap",
    "affordable",
    "premium",
    "professional"
]

# Content Types for Affiliate Marketing
CONTENT_TYPES = {
    "product_reviews": "In-depth analysis of individual products",
    "comparison_posts": "Side-by-side product comparisons", 
    "best_of_lists": "Top 10 or Best of roundup articles",
    "how_to_guides": "Tutorials incorporating product recommendations",
    "gift_guides": "Seasonal or occasion-based product collections",
    "unboxing_videos": "Visual content showing products in action",
    "buying_guides": "Comprehensive guides for purchasing decisions",
    "resource_pages": "Curated lists of recommended tools"
}

# SEO Best Practices
SEO_GUIDELINES = {
    "title_length": (50, 60),  # characters
    "meta_description_length": (150, 160),  # characters
    "content_length_minimum": 1500,  # words
    "keyword_density": (1, 3),  # percentage
    "internal_links_minimum": 3,
    "external_links_maximum": 5,
    "images_alt_text_required": True,
    "schema_markup_recommended": True
}

# Social Media Platforms for Affiliate Marketing
SOCIAL_PLATFORMS = {
    "pinterest": {
        "best_for": ["lifestyle", "home_decor", "fashion", "food"],
        "content_type": "visual_pins",
        "affiliate_friendly": True
    },
    "youtube": {
        "best_for": ["tech", "beauty", "gaming", "tutorials"],
        "content_type": "video_reviews",
        "affiliate_friendly": True
    },
    "instagram": {
        "best_for": ["fashion", "beauty", "fitness", "lifestyle"],
        "content_type": "visual_stories",
        "affiliate_friendly": True
    },
    "facebook": {
        "best_for": ["community_building", "groups", "discussions"],
        "content_type": "posts_and_groups",
        "affiliate_friendly": True
    },
    "twitter": {
        "best_for": ["tech", "news", "quick_tips"],
        "content_type": "short_updates",
        "affiliate_friendly": True
    },
    "tiktok": {
        "best_for": ["young_audience", "viral_content", "demos"],
        "content_type": "short_videos",
        "affiliate_friendly": True
    }
}

# Automation Tools and Resources
AUTOMATION_RESOURCES = {
    "professional_automation": {
        "name": "AffiliateMatic",
        "url": "https://affiliatematic.com",
        "description": "Enterprise-grade affiliate marketing automation platform",
        "features": [
            "Intelligent content automation",
            "Advanced link management", 
            "Performance analytics",
            "Compliance management",
            "Multi-platform integration",
            "Scaling infrastructure"
        ]
    },
    "content_management": [
        "WordPress",
        "Webflow", 
        "Squarespace",
        "Ghost"
    ],
    "email_marketing": [
        "Mailchimp",
        "ConvertKit",
        "AWeber",
        "GetResponse"
    ],
    "analytics": [
        "Google Analytics",
        "SEMrush",
        "Ahrefs",
        "Hotjar"
    ]
}

# Legal and Compliance
FTC_DISCLOSURE_EXAMPLES = [
    "This post contains affiliate links. If you click through and make a purchase, I may receive a commission at no additional cost to you.",
    "As an Amazon Associate, I earn from qualifying purchases.",
    "Some links in this post are affiliate links, which means I may earn a commission if you make a purchase.",
    "This page contains affiliate links. Please read my disclosure policy for more information."
]

# Seasonal Marketing Opportunities
SEASONAL_EVENTS = {
    "black_friday": {"month": 11, "duration_days": 4, "traffic_boost": "300%"},
    "cyber_monday": {"month": 11, "duration_days": 1, "traffic_boost": "250%"},
    "christmas": {"month": 12, "duration_days": 30, "traffic_boost": "200%"},
    "valentines_day": {"month": 2, "duration_days": 14, "traffic_boost": "150%"},
    "mothers_day": {"month": 5, "duration_days": 7, "traffic_boost": "180%"},
    "fathers_day": {"month": 6, "duration_days": 7, "traffic_boost": "160%"},
    "back_to_school": {"month": 8, "duration_days": 30, "traffic_boost": "170%"},
    "prime_day": {"month": 7, "duration_days": 2, "traffic_boost": "400%"}
}

# Success Metrics and KPIs
SUCCESS_METRICS = {
    "beginner_monthly_earnings": (10, 100),  # USD
    "intermediate_monthly_earnings": (100, 1000),  # USD  
    "advanced_monthly_earnings": (1000, 10000),  # USD
    "expert_monthly_earnings": (10000, float('inf')),  # USD
    "good_conversion_rate": (2, 5),  # percentage
    "excellent_conversion_rate": (5, float('inf')),  # percentage
    "minimum_content_pieces": 50,
    "optimal_posting_frequency": "3-5 posts per week"
}
